```{include} readme.md
:relative-docs: docs/
:relative-images:
```

## Contents

```{toctree}
Overview & Quick Start <readme>
License <license>
Authors <authors>
changelog
contributing
Module Reference <api/modules>
```


## Indices and tables

```{eval-rst}
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
```
